@@ -63,8 +63,8 @@ class RegionEstimator(object):
                     "actuals['" + column + "'] column contains non-numeric values (null values accepted)."
 
         # Check that each sensor ID is present in the sensors dataframe index.
-        #allowed_sensors = sensors.index
-        #print(allowed_sensors)
+        allowed_sensors = sensors.index.values
+        print(allowed_sensors)
         #assert  , "Each sensor ID must match a sensor_id in sensors."
 
         assert len(list(actuals.columns)) > 2, "There are no measurement value columns in the actuals dataframe."
